@@ -8,12 +8,13 @@ from scraper_helper.html import html_decode
 from scraper_helper.text import cleanup
 from scraper_helper.text import get_dict
 from scraper_helper.text import get_headers
+from scraper_helper.text import headers
 from scraper_helper.url import change_param
 from scraper_helper.url import get_query_str_val
 from scraper_helper.url import get_root_address
 from scraper_helper.url import strip_qs_params
 
-__version__ = '0.0.4'
+__version__ = '0.0.6'
 __all__ = [
     'change_param',
     'get_query_str_val',
@@ -28,4 +29,5 @@ __all__ = [
     'html_decode',
     'cleanup',
     'get_headers',
-    'get_dict']
+    'get_dict',
+    'headers']
